@@ -19,6 +19,7 @@ from __future__ import annotations
 from aiohomekit.crypto.chacha20poly1305 import (
     ChaCha20Poly1305Decryptor,
     ChaCha20Poly1305Encryptor,
+    ChaCha20Poly1305PartialTag,
 )
 
 
@@ -45,3 +46,14 @@ class DecryptionKey:
         data = self.key.decrypt(b"", counter, bytes([0, 0, 0, 0]), data)
         self.counter += 1
         return data
+
+
+class BroadcastDecryptionKey:
+    def __init__(self, key: bytes) -> None:
+        self.key = ChaCha20Poly1305PartialTag(key)
+
+    def decrypt(
+        self, data: bytes | bytearray, gsn: int, advertising_identifier: bytes
+    ) -> bytes | bool:
+        gsn_bytes = b"\x00\x00\x00\x00" + gsn.to_bytes(8, byteorder="little")
+        return self.key.open(gsn_bytes, data, advertising_identifier)
